==> huaweicloudsdkcloudtest-3.1.142-py2.py3-none-any.whl: huaweicloudsdkcloudtest/v1/model/import_factor_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ImportFactorRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'excel_file': 'file'
    }

    attribute_map = {
        'excel_file': 'excel_file'
    }

    def __init__(self, excel_file=None):
        """ImportFactorRequestBody

        The model defined in huaweicloud sdk

        :param excel_file: 待导入文件
        :type excel_file: :class:`huaweicloudsdkcore.http.formdata.FormFile`
        """
        
        

        self._excel_file = None
        self.discriminator = None

        self.excel_file = excel_file

    @property
    def excel_file(self):
        """Gets the excel_file of this ImportFactorRequestBody.

        待导入文件

        :return: The excel_file of this ImportFactorRequestBody.
        :rtype: :class:`huaweicloudsdkcore.http.formdata.FormFile`
        """
        return self._excel_file

    @excel_file.setter
    def excel_file(self, excel_file):
        """Sets the excel_file of this ImportFactorRequestBody.

        待导入文件

        :param excel_file: The excel_file of this ImportFactorRequestBody.
        :type excel_file: :class:`huaweicloudsdkcore.http.formdata.FormFile`
        """
        self._excel_file = excel_file

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImportFactorRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcloudtest-3.1.157-py2.py3-none-any.whl: huaweicloudsdkcloudtest/v1/model/import_factor_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ImportFactorRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'excel_file': 'file'
    }

    attribute_map = {
        'excel_file': 'excel_file'
    }

    def __init__(self, excel_file=None):
        r"""ImportFactorRequestBody

        The model defined in huaweicloud sdk

        :param excel_file: 待导入文件
        :type excel_file: :class:`huaweicloudsdkcore.http.formdata.FormFile`
        """
        
        

        self._excel_file = None
        self.discriminator = None

        self.excel_file = excel_file

    @property
    def excel_file(self):
        r"""Gets the excel_file of this ImportFactorRequestBody.

        待导入文件

        :return: The excel_file of this ImportFactorRequestBody.
        :rtype: :class:`huaweicloudsdkcore.http.formdata.FormFile`
        """
        return self._excel_file

    @excel_file.setter
    def excel_file(self, excel_file):
        r"""Sets the excel_file of this ImportFactorRequestBody.

        待导入文件

        :param excel_file: The excel_file of this ImportFactorRequestBody.
        :type excel_file: :class:`huaweicloudsdkcore.http.formdata.FormFile`
        """
        self._excel_file = excel_file

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImportFactorRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
